#include "c_actor.h"
#include "c_game.h"
#include "c_sprite.h"
#include <stdio.h>

using namespace std;

c_actor::c_actor()
{
	_init();
}

c_actor::c_actor(c_game *game, string dat_file)
{
	_init();
	
	m_p_game = game;
	if (dat_file != "")
		load_dat_file(dat_file);
}

c_actor::~c_actor()
{
	if (m_sprite != NULL)
	{
		delete m_sprite;
		m_sprite = NULL;
	}
}

void c_actor::_init(void)
{
	m_p_game = NULL;
	m_sprite = NULL;
	m_total_anims = 0;
	m_x = m_y = m_xvel = m_yvel = 0.0;
}

void c_actor::load_dat_file(string dat_file)
{
	FILE *f = fopen(dat_file.c_str(), "r");
	char buf[256];
	string sprite_file, anim_ID, anim_type;
	int tile_w = 0, tile_h = 0, frame_count = 0, speed = 0, x = 0, y = 0, new_anim_ID = -1;
	ANIM_TYPE at;

	if (f)
	{
		// Read sprite file name
		fscanf(f, "%255s", buf);
		
		// Read tile width, then height
		fscanf(f, "%d", &tile_w);
		fscanf(f, "%d", &tile_h);
		
		sprite_file.assign(buf);
		m_sprite = new c_sprite(m_p_game, sprite_file, tile_w, tile_h);
		
		if (m_sprite != NULL)
		{
			// Read in all animations
			while (!feof(f))
			{
				// Read animation ID
				fscanf(f, "%4s", buf);
				anim_ID.assign(buf);
				
				// Read animation type
				fscanf(f, "%4s", buf);
				anim_type.assign(buf);
				if (anim_type == "LOOP")
					at = AT_LOOP;
				else if (anim_type == "PPNG")
					at = AT_PINGPONG;
				else if (anim_type == "ONES")
					at = AT_ONESHOT;
				else
					at = AT_LOOP;
				
				// Read frame count
				fscanf(f, "%d", &frame_count);
				
				// Read speed
				fscanf(f, "%d", &speed);
				
				new_anim_ID = m_sprite->add_anim(at, frame_count, speed);
				
				// Read in all x,y pairs and add frames
				for (int i = 0; i < frame_count; i++)
				{
					fscanf(f, "%d,%d", &x, &y);
					m_sprite->add_anim_frame(new_anim_ID, x, y);
				}
				
				m_anims[new_anim_ID] = anim_ID;
				m_total_anims++;
			}
		}
		
		fclose(f);
	}
}

string c_actor::get_anim(void)
{
	int anim_ID = m_sprite->get_anim();
	
	if (anim_ID > -1)
		return m_anims[m_sprite->get_anim()];
	else
		return NULL;
}

bool c_actor::set_anim(string anim_ID)
{
	bool f_result = false;
	
	// Loop through all anims to look for mathing anim ID
	for (int i = 0; i < m_total_anims; i++)
	{
		if (m_anims[i] == anim_ID)
		{
			// This is the animation, set it in the sprite and break
			m_sprite->set_anim(i);
			f_result = true;
			break;
		}
	}
	
	return f_result;
}

void c_actor::draw(BITMAP *bmp_dest)
{
	m_sprite->draw(bmp_dest, (int)m_x, (int)m_y);
}

void c_actor::update(void)
{
	m_x += m_xvel;
	m_y += m_yvel;
}

void c_actor::set_x(float x)
{
	m_x = x;
}

void c_actor::set_y(float y)
{
	m_y = y;
}

float c_actor::get_x(void)
{
	return m_x;
}

float c_actor::get_y(void)
{
	return m_y;
}

void c_actor::set_xvel(float x_vel)
{
	m_xvel = x_vel;
}

void c_actor::set_yvel(float y_vel)
{
	m_yvel = y_vel;
}

float c_actor::get_xvel(void)
{
	return m_xvel;
}

float c_actor::get_yvel(void)
{
	return m_yvel;
}

c_sprite* c_actor::get_sprite(void)
{
	return m_sprite;
}
