#ifndef C_ENEMY_H
#define C_ENEMY_H

#include "c_character_actor.h"

/* The enemy projectile speed in pixels per frame */
#define ENEMY_PROJECTILE_SPEED   15.0

/* The number of frames to wait before allowing the enemy to fire again */
#define ENEMY_PROJECTILE_LIMITER  7

/* The state in which an enemy can be: -
 *  - ES_SPAWNING:     the enemy is spawning.
 *  - ES_CHASING:      the enemy is chasing the player.
 *  - ES_FLEEING:      the enemy is running away from the player.
 *  - ES_ATTACK_GUN:   the enemy is firing at the player.
 *  - ES_ATTACK_MELEE: currently unused.
 *  - ES_DYING:        the enemy has been killed and is in the process of dying.
 *  - ES_DEAD:         the enemy is no more... ready to be destroyed by c_game.
 */
enum ENEMY_STATE { ES_SPAWNING, ES_CHASING, ES_FLEEING, ES_ATTACK_GUN, ES_ATTACK_MELEE, ES_DYING, ES_DEAD };

/* Class:  c_enemy
 * Parent: c_character_actor
 * 
 * Encapsulates a game enemy. Builds on c_character_actor for health, hit
 * handling etc.
 */
class c_enemy : public c_character_actor
{
private:
	ENEMY_STATE m_state;
	ENEMY_STATE m_prev_state;
	int m_bullet_timer; // To limit firing rate
	int m_kill_score;   // The score to award the player on killing this enemy
	
	/* Internal method used to fire a projectile from the enemy
	 * Arguments: -
	 *  - vx, vy: velocity vector for the projectile.
	 */
	void fire_projectile(float vx, float vy);
public:
	c_enemy();
	
	/* Overloaded constructor
	 * Arguments: -
	 *  - game:     pointer to the main c_game object.
	 *  - dat_file: file name of the character actor data file.
	 */
	c_enemy(c_game *game, string dat_file);
	
	~c_enemy();
	
	/* Overloaded c_actor::update()
	 * Updates the enemy (movement, AI, firing etc).
	 */
	void update(void);
	
	/* Getters and setters for enemy state and kill score */
	void set_state(ENEMY_STATE state);
	ENEMY_STATE get_state(void);
	void set_kill_score(int score);
	int get_kill_score(void);
};

#endif
