#include "c_jukebox.h"

c_jukebox::c_jukebox()
{
	_init();
}

c_jukebox::~c_jukebox()
{
	// Destroy each track if it's loaded
	for (int i = 0; i < JUKEBOX_NUM_TRACKS; i++)
	{
		if (m_a_tracks[i] != NULL)
		{
			delete m_a_tracks[i];
			m_a_tracks[i] = NULL;
		}
	}
}

void c_jukebox::_init(void)
{
	for (int i = 0; i < JUKEBOX_NUM_TRACKS; i++)
		m_a_tracks[i] = NULL;
	
	m_curr_track = JBT_NONE;
}

bool c_jukebox::load_track(JUKEBOX_TRACK track, string filename)
{
	// Return false if track type is invalid
	if (track < 0 || track >= JUKEBOX_NUM_TRACKS)
		return false;
	
	// If there is currently a track of this type loaded, destroy it
	if (m_a_tracks[track] != NULL)
	{
		delete m_a_tracks[track];
		m_a_tracks[track] = NULL;
	}
	
	m_a_tracks[track] = new c_music;
	if (m_a_tracks[track] == NULL)
		return false;
	
	return m_a_tracks[track]->load_wav_file(filename);
}

void c_jukebox::play_track(JUKEBOX_TRACK track, bool f_restart)
{
	// Just stop the current track if the type is JBT_NONE
	if (track == JBT_NONE)
	{
		if (m_curr_track > -1 && m_curr_track < JUKEBOX_NUM_TRACKS)
			m_a_tracks[m_curr_track]->stop();
		return;
	}
	
	// Check that track is valid
	if (track < 0 || track >= JUKEBOX_NUM_TRACKS)
		return;
	
	// Check that track is loaded
	if (m_a_tracks[track] == NULL)
		return;
	
	// If restart is not requested and the current track is the one requested, do nothing
	if (!f_restart && m_curr_track == track)
		return;
	
	// Stop the current track if applicable
	if (m_curr_track > -1 && m_curr_track < JUKEBOX_NUM_TRACKS)
		m_a_tracks[m_curr_track]->stop();
	
	// Play the track
	m_a_tracks[track]->play();
	m_curr_track = track;
}

JUKEBOX_TRACK c_jukebox::get_current_track(void)
{
	return m_curr_track;
}
