#include "c_particle.h"

c_particle::c_particle(unsigned char r, unsigned char g, unsigned char b, char size, float x, float y, float xvel, float yvel, float damp_x, float damp_y, int lifespan)
{
	m_f_dead = false;
	m_col = makecol(r, g, b);
	m_size = size;
	m_x = x;
	m_y = y;
	m_xvel = xvel;
	m_yvel = yvel;
	m_damp_x = damp_x;
	m_damp_y = damp_y;
	m_lifespan = lifespan;
	m_age = 0;
	m_p_next = NULL;
}

c_particle::~c_particle()
{
}

void c_particle::update(void)
{
	if (m_f_dead)
		return;
		
	// Damp the velocity
	m_xvel *= m_damp_x;
	m_yvel *= m_damp_y;
	
	// Move the particle
	m_x += m_xvel;
	m_y += m_yvel;
	
	// Increase age and deactiveate particle if it exceeds its lifespan
	m_age++;
	if (m_age >= m_lifespan)
		m_f_dead = true;
}

void c_particle::draw(BITMAP *bmp_dest)
{
	if (m_size == 1)
	{
		// Plot a single pixel
		putpixel(bmp_dest, (int)m_x, (int)m_y, m_col);
	}
	else
	{
		// Draw a filled circle
		circlefill(bmp_dest, (int)m_x, (int)m_y, m_size, m_col);
	}
}

bool c_particle::is_dead(void)
{
	return m_f_dead;
}

void c_particle::set_next(c_particle *next)
{
	m_p_next = next;
}

c_particle* c_particle::get_next(void)
{
	return m_p_next;
}
