#ifndef C_PLAYER_H
#define C_PLAYER_H

#include "c_character_actor.h"

/* The player's maximum health */
#define PLAYER_HEALTH_MAX        250.0

/* The player health recharge rate (per frame) */
#define PLAYER_HEALTH_RECHARGE     0.05

/* The player's projectile speed (pixels per frame) */
#define PLAYER_PROJECTILE_SPEED   20.0

/* The number of frames to wait before allowing the player to fire again */
#define PLAYER_PROJECTILE_LIMITER  7

/* Player state  enum: -
 *  - PLS_ALIVE: player is alive and controllable.
 *  - PLS_DYING: player is in the process of dying and uncontrollable.
 *  - PLS_DEAD:  player is dead and uncontrollable.
 */
enum PLAYER_STATE { PLS_ALIVE, PLS_DYING, PLS_DEAD };

/* Class:  c_player
 * Parent: c_character_actor
 * 
 * Encapsulates the controllable player for the game. Builds on
 * c_character_actor for health, hit handling etc.
 */
class c_player : public c_character_actor
{
private:
	PLAYER_STATE m_state;
	int m_bullet_timer; // Timer to limit firing rate
	
	/* Internal function used to fire a projectile from the player
	 * Arguments: -
	 *  - vx, vx: the projectile velocity vector.
	 */
	void fire_projectile(float vx, float vy);
public:
	c_player();
	
	/* Overloaded constructor
	 * Arguments: -
	 *  - game:     pointer to the main c_game object.
	 *  - dat_file: file name of the character actor data file.
	 */
	c_player(c_game *game, string dat_file);
	
	~c_player();
	
	/* Getter and setter for player state. Setter also sets appropriate animation */
	void set_state(PLAYER_STATE state);
	PLAYER_STATE get_state(void);
	
	/* Overloaded c_actor::update()
	 * Updates the player (keyboard and mouse handling, movement, animations etc).
	 */
	void update(void);
};

#endif
