#ifndef C_POWERUP_H
#define C_POWERUP_H

#include "c_actor.h"

/* The type of powerup, currently only one type defined (health) */
enum POWERUP_TYPE { PT_HEALTH };

/* Class:  c_powerup
 * Parent: c_actor
 * 
 * Encapsulates a powerup item for the game. Builds on c_actor for sprite,
 * position etc
 */
class c_powerup : public c_actor
{
private:
	POWERUP_TYPE m_type;
	float m_value;   // The "value" of the powerup (for health, the amount of health increase it provides)
	int m_lifespan;  // For how many frames the powerup will exist
	bool m_f_active;
public:
	/* Overloaded constructor
	 * Arguments: -
	 *  - game:     pointer to the main c_game object.
	 *  - dat_file: the file name of the actor data file to use.
	 *  - type:     the type of powerup.
	 *  - value:    the value that the powerup will provide.
	 *  - lifespan: the number of frames for which the powerup will exist.
	 */
	c_powerup(c_game *game, string dat_file, POWERUP_TYPE type, float value, int lifespan);
	
	~c_powerup();

	/* Overloaded c_actor::draw()
	 * Draws the powerup to a BITMAP.
	 * Argument: -
	 *  - bmp_dest: pointer to the target BITMAP to draw to.
	 */
	void draw(BITMAP *bmp_dest);
	
	/* Overloaded c_actor::update()
	 * Updates the powerup (decreases lifespan etc).
	 */
	void update(void);
	
	/* Getters and setters for type, value and active flag */
	POWERUP_TYPE get_type(void);
	float get_value(void);
	bool is_active(void);
	void deactivate(void);
};

#endif
