#include "c_projectile.h"
#include "c_sprite.h"

c_projectile::c_projectile()
{
	_init();
}

c_projectile::c_projectile(c_game *game, string dat_file):c_actor(game, dat_file)
{
	_init();
	m_dat_file = dat_file;
	m_f_active = true;
}

c_projectile::~c_projectile()
{
}

void c_projectile::_init(void)
{
	m_f_active    = false;
	m_damage_type = DT_BOTH;
	m_dat_file    = "";
	set_state(PS_DEAD);
}

void c_projectile::update(void)
{
	// If the state is PS_NORMAL, call c_actor::update(). If it's PS_DYING,
	// set the state to PS_DEAD and deactivate it if the dying animation is complete.
	switch (m_state)
	{
		case PS_NORMAL:
			if (m_f_active)
				c_actor::update();
			break;
		case PS_DYING:
			if (m_sprite->is_curr_anim_finished())
			{
				set_state(PS_DEAD);
				m_f_active = false;
			}
			break;
	}
}

void c_projectile::draw(BITMAP *bmp_dest)
{
	if (m_f_active)
		c_actor::draw(bmp_dest);
}

void c_projectile::activate(void)
{
	m_f_active = true;
}

void c_projectile::deactivate(void)
{
	set_state(PS_DYING);
}

bool c_projectile::is_active(void)
{
	return m_f_active;
}

string c_projectile::get_dat_file_name(void)
{
	return m_dat_file;
}

DAMAGE_TYPE c_projectile::get_damage_type(void)
{
	return m_damage_type;
}

void c_projectile::set_damage_type(DAMAGE_TYPE dt)
{
	m_damage_type = dt;
}

void c_projectile::set_damage_power(float power)
{
	m_damage_power = power;
}

float c_projectile::get_damage_power(void)
{
	return m_damage_power;
}

PROJECTILE_STATE c_projectile::get_state(void)
{
	return m_state;
}

void c_projectile::set_state(PROJECTILE_STATE state)
{
	// Sets the state and also the appropriate sprite animation.
	switch (state)
	{
		case PS_NORMAL:
			set_anim("IDLE");
			m_state = PS_NORMAL;
			break;
		case PS_DYING:
			set_anim("DYIG");
			m_state = PS_DYING;
			break;
		case PS_DEAD:
			set_anim("IDLE");
			m_state = PS_DEAD;
			break;
	}
}
