#ifndef C_SFX_H
#define C_SFX_H

#include <allegro.h>

/* The number of defined samples in the enum below */
#define SFX_SAMPLE_COUNT 8

/* Enum for each sample type */
enum SFX_TYPE { SFX_PLAYER_FIRE, SFX_ENEMY_FIRE, SFX_ENEMY_HIT, SFX_ENEMY_DIE, SFX_PLAYER_HIT, SFX_PLAYER_DIE, SFX_HEALTH_PICKUP, SFX_WALL_HIT };

/* Struct to store linked list of voices */
typedef struct _voice_list
{
	SFX_TYPE     type;
	SAMPLE      *p_sample; // Pointer to the Allegro SAMPLE
	int          voice_id; // Allegro ID of the voice 
	int          vol;      // Volume
	_voice_list *p_next;
} voice_list;

/* Class: c_sfx
 * 
 * Allows loading and playing of sound effects.
 */
class c_sfx
{
private:
	bool m_f_enabled; // If not enabled, all calls to play_sfx() will do nothing
	SAMPLE *m_a_samples[SFX_SAMPLE_COUNT]; // Array of Allegro SAMPLE*
	voice_list *m_p_voice_list; // Voices linked list
	
	/* Internal method to load all voices
	 * Return: true on success, false on failure.
	 */
	bool load_voices(void);
public:
	c_sfx();
	~c_sfx();
	
	/* Plays a sound effect
	 * Argument: -
	 *  - type: the type of SFX to play (see enum above).
	 */
	void play_sfx(SFX_TYPE type);
	
	/* Enables or disables SFX
	 * Argument: -
	 *  - f_enabled: true to enable SFX, false to disable.
	 */
	void set_enabled(bool f_enabled);
	
	/* Indicates whether SFX are enabled
	 * Return: true if enabled, false if disabled
	 */
	bool is_enabled(void);
};

#endif
